@@ -2,7 +2,7 @@ package Algorithm::CurveFit::Simple;
 
 # ABSTRACT: Convenience wrapper around Algorithm::CurveFit.
 
-our $VERSION = '1.00'; # VERSION 1.00
+our $VERSION = '1.01'; # VERSION 1.01
 
 use strict;
 use warnings;
@@ -14,7 +14,7 @@ our %STATS_H;  # side-products of fit() stored here for profiling purposes
 
 BEGIN {
     require Exporter;
-    our $VERSION = '1.00';
+    our $VERSION = '1.01';
     our @ISA = qw(Exporter);
     our @EXPORT_OK = qw(fit %STATS_H);
 }
@@ -322,7 +322,7 @@ Algorithm::CurveFit::Simple - Convenience wrapper around Algorithm::CurveFit
     my ($max_dev, $avg_dev, $src) = fit(xdata => \@xdata, ydata => \@ydata, ..options..);
 
     # Alternatively pass xdata and ydata together:
-    my ($max_dev, $avg_dev, $src) = fit(xydata => [@xdata, @ydata], ..options..);
+    my ($max_dev, $avg_dev, $src) = fit(xydata => [\@xdata, \@ydata], ..options..);
 
     # Alternatively pass data as array of [x,y] pairs:
     my ($max_dev, $avg_dev, $src) = fit(xydata => [[1, 2], [2, 5], [3, 10]], ..options..);
